@@ -2,7 +2,6 @@ use crate::error::Result;
 use crate::expression::parser::parse;
 
 use crate::expression::column_usage::{ColumnUsage, DatasetsColumnUsage, VlSelectionFields};
-use crate::expression::escape::unescape_field;
 use crate::spec::transform::{TransformColumns, TransformSpecTrait};
 use crate::spec::values::{Field, SignalExpressionSpec};
 use crate::task_graph::graph::ScopedVariable;
@@ -11,6 +10,7 @@ use crate::task_graph::task::InputVariable;
 use serde::{Deserialize, Serialize};
 use serde_json::Value;
 use std::collections::{HashMap, HashSet};
+use vegafusion_common::escape::unescape_field;
 
 #[derive(Debug, Clone, PartialEq, Serialize, Deserialize)]
 pub struct BinTransformSpec {
