@@ -1,8 +1,8 @@
 use crate::expression::column_usage::{ColumnUsage, DatasetsColumnUsage, VlSelectionFields};
-use crate::expression::escape::unescape_field;
 use serde::{Deserialize, Serialize};
 use serde_json::Value;
 use std::collections::HashMap;
+use vegafusion_common::escape::unescape_field;
 
 use crate::spec::transform::{TransformColumns, TransformSpecTrait};
 use crate::spec::values::CompareSpec;
